/*
 * Copyright © 2000 Eazel, Inc.
 * Copyright © 2002 Dom Lachowicz
 * Copyright © 2007-2009 Emmanuel Pacaud
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Authors:
 * 	Raph Levien <raph@artofcode.com>
 * 	Dom Lachowicz <cinamod@hotmail.com>
 *	Emmanuel Pacaud <emmanuel@gnome.org>
 */

#ifndef LSM_SVG_COLORS_H
#define LSM_SVG_COLORS_H

#include <lsmsvgtypes.h>

G_BEGIN_DECLS

unsigned int lsm_svg_color_from_string (const char *name);

G_END_DECLS

#endif
